@@ -455,17 +455,18 @@ def critical_exception(
 def badOutcome(
 ####+END:
         outcome,
+        outcomeInfo=None,
 ):
     """ #+begin_org
 ** [[elisp:(org-cycle)][| *DocStr | ]
     #+end_org """
 
-    print("io.eh.badOutcome: InvokedBy {invokerName}, Operation Failed: Stdcmnd={stdcmnd} Error={status} -- {errInfo}".
-           format(invokerName=outcome.invokerName,
-               stdcmnd=outcome.stdcmnd,
-               status=outcome.error,
-               errInfo=outcome.errInfo,
-                  ),  file=sys.stderr)   
+    outcomeInfoStr=""
+    if outcomeInfo is not None:
+        outcomeInfoStr=f" -- {outcomeInfo}"
+
+    print(f"io.eh.badOutcome: {outcomeInfoStr} -- InvokedBy NOTYET, Operation Failed: Stdcmnd={outcome.stdcmnd} Error={outcome.error} -- {outcome.errInfo}"
+          , file=sys.stderr)
     print(('io.eh.: ' + ' -- ' + b.ast.stackFrameInfoGet(2) ), file=sys.stderr)
 
     return outcome
