@@ -25,6 +25,7 @@
 """ #+begin_org
 * *[[elisp:(org-cycle)][| Particulars-csInfo |]]*
 #+end_org """
+from ast import Pass
 import typing
 csInfo: typing.Dict[str, typing.Any] = { 'moduleName': ['examples'], }
 csInfo['version'] = '202209241240'
@@ -118,7 +119,8 @@ class commonExamples(cs.Cmnd):
         print(( G_myName + " -i describe" ))
         print(( G_myName + " -i describe" + " |" + " emlVisit"))
         print(( G_myName + " -i examples" ))
-        print(( G_myName + " -i examples" + " |" + " icmToEmlVisit"))
+        print(f"{G_myName} -i examples | emlOutFilter.sh -i iimToEmlStdout  | emlVisit")
+        # print(( G_myName + " -i examples" + " |" + " icmToEmlVisit"))
 
         return(cmndOutcome)
 
@@ -130,6 +132,7 @@ class commonExamples(cs.Cmnd):
 @cs.track(fnLoc=True, fnEntry=True, fnExit=True)
 def commonBrief(
 ####+END:
+        roMenu=False,
         interactive=False,
 ) -> None:
     """ #+begin_org
@@ -139,25 +142,30 @@ def commonBrief(
     G_myFullName = sys.argv[0]
     G_myName = os.path.basename(G_myFullName)
 
-    menuChapter('/Intercatively Invokable Module (ICM) Brief Usage Model/')
+    menuChapter('/Command Service (CS) Brief Usage/')
 
     print(( G_myName + " -i commonExamples" + "    # Help, Model, icmOptionsExample"))
     print(( G_myName + " -i describe" + " |" + " emlVisit"))
-    print(( G_myName + " -i examples" + " |" + " icmToEmlVisit"))
+    # print(( G_myName + " -i examples" + " |" + " icmToEmlVisit"))
+    print(f"{G_myName} -i examples | emlOutFilter.sh -i iimToEmlStdout  | emlVisit")
     print(( G_myName + " -i visit"))
     print(( """emlVisit -v -n showRun -i gotoPanel """ + G_myFullName))
 
+    invokerName = cs.ro.csMuInvokerName()
+    performerName = cs.ro.csMuPerformerName()
+
     if cs.ro.csMuIsDirect() is True:
-        menuChapter('/Remote Operations -- Performer And Invoker/')
+        if roMenu is True:
+            menuChapter('/Remote Operations -- Performer And Invoker/')
 
-        # print(f"""csRo-manage.cs --perfName="localhost" --rosmu="{G_myName}"  -i ro_sapCreate""")
-        # print(f"""{G_myName} --perfName="localhost" -i csPerformer  & # in background Start rpyc CS Service""")
-        # print(f"""csRo-manage.cs --perfName="localhost" --rosmu="{G_myName}"  -i ro_fps list""")
-        # print(f"""{G_myName}  --perfName="localhost" -i examples""")
+            # print(f"""csRo-manage.cs --perfName="localhost" --rosmu="{G_myName}"  -i ro_sapCreate""")
+            # print(f"""{G_myName} --perfName="localhost" -i csPerformer  & # in background Start rpyc CS Service""")
+            # print(f"""csRo-manage.cs --perfName="localhost" --rosmu="{G_myName}"  -i ro_fps list""")
+            # print(f"""{G_myName}  --perfName="localhost" -i examples""")
 
-        print(( G_myName + " -i roEnable" + "    # Create Symlinks For roPerf- and roInv-"))
-        print(( "roPerf-" + G_myName + "    # Remote Operations Performer"))
-        print(( "roInv-" + G_myName  + "    # Remote Operations Invoker"))
+            print(( G_myName + " -i roEnable" + "    # Create Symlinks For -roPerf and -roInv"))
+            print(( invokerName + "    # Remote Operations Performer"))
+            print(( performerName + "   # Remote Operations Invoker"))
 
     elif cs.ro.csMuIsPerformer() is True:
         menuChapter('/Direct Commands and roInvoker/')
@@ -197,7 +205,7 @@ def devExamples(
 
     print("======== Development =========")
 
-    print(("python -m trace -l " + G_myName + " | egrep -v " + '\'/python2.7/|\<string\>\''))
+    # print(("python -m trace -l " + G_myName + " | egrep -v " + '\'/python2.7/|\<string\>\''))
     print(("python -m trace -l " + G_myName))
     print(("python -m trace -t " + G_myName))
 
@@ -254,7 +262,12 @@ def myName(
 
     print(f"#######    *{myName}*    ##########")
     print(f"=======  {myFullName}   ===========")
-
+    if cs.G.seedOfThisPlant is None:
+        pass
+        # print("UnSeeded")
+    else:
+        print(f"=======  PlantedCSU :: {cs.G.plantOfThisSeed}   ===========")
+        print(f"=======  Seed :: {cs.G.seedOfThisPlant}   ===========")
 
 ####+BEGIN: b:py3:cs:func/typing :funcName "ex_gCommon" :funcType "extTyped" :deco "track"
 """ #+begin_org
@@ -286,6 +299,19 @@ def ex_gCommon(
 #+end_org """
 ####+END:
 
+####+BEGIN: b:py3:cs:func/typing :funcName "menuPart" :funcType "extTyped" :deco "track"
+""" #+begin_org
+*  _[[elisp:(blee:menu-sel:outline:popupMenu)][±]]_ _[[elisp:(blee:menu-sel:navigation:popupMenu)][Ξ]]_ [[elisp:(outline-show-branches+toggle)][|=]] [[elisp:(bx:orgm:indirectBufOther)][|>]] *[[elisp:(blee:ppmm:org-mode-toggle)][|N]]*  F-T-extTyped [[elisp:(outline-show-subtree+toggle)][||]] /menuPart/  deco=track  [[elisp:(org-cycle)][| ]]
+#+end_org """
+@cs.track(fnLoc=True, fnEntry=True, fnExit=True)
+def menuPart(
+####+END:
+        title: str,
+) -> None:
+    """ #+begin_org
+** [[elisp:(org-cycle)][| *DocStr | ]
+    #+end_org """
+    print(("@@@@@@@@  " + title + "  @@@@@@@@@"))
 
 ####+BEGIN: b:py3:cs:func/typing :funcName "menuChapter" :funcType "extTyped" :deco "track"
 """ #+begin_org
@@ -301,7 +327,6 @@ def menuChapter(
     #+end_org """
     print(("#######  " + title + "  ##########"))
 
-
 ####+BEGIN: b:py3:cs:func/typing :funcName "menuSection" :funcType "extTyped" :deco "track"
 """ #+begin_org
 *  _[[elisp:(blee:menu-sel:outline:popupMenu)][±]]_ _[[elisp:(blee:menu-sel:navigation:popupMenu)][Ξ]]_ [[elisp:(outline-show-branches+toggle)][|=]] [[elisp:(bx:orgm:indirectBufOther)][|>]] *[[elisp:(blee:ppmm:org-mode-toggle)][|N]]*  F-T-extTyped [[elisp:(outline-show-subtree+toggle)][||]] /menuSection/  deco=track  [[elisp:(org-cycle)][| ]]
